@@ -32,7 +32,7 @@ class EnvironmentTest(TestCase):
 
     def test_simple_app_creation(self):
         env = Environment()
-        app = env.application({})
+        app = env._application({})
         self.assertIsInstance(app, Application)
         self.assertEqual(len(app.handlers), 0)
 
@@ -52,7 +52,7 @@ class EnvironmentTest(TestCase):
 
         self.assertEqual(len(env._handlers), 1)
 
-        app = env.application({})
+        app = env._application({})
         self.assertEqual(len(app.handlers), 1)
         (host_pattern, [spec]) = app.handlers[0]
         self.assertEqual(host_pattern.pattern, '.*$')
@@ -75,11 +75,11 @@ class EnvironmentTest(TestCase):
         with self.assertRaises(AssertionError):
             env.add_managed_object('i_am_managed', object())
 
-    def test_finalizing_managed_objects(self):
+    def test_finalizing(self):
         env = Environment()
         managed = object()
         env.add_managed_object('i_am_managed', managed)
-        env.finalize_managed_objects()
+        env._finalize()
 
         with self.assertRaises(AssertionError):
             env.add_managed_object('another_managed', object())
